#include <windows.h>
#include <commctrl.h>
#include "dsp.h"

BOOL WINAPI _DllMainCRTStartup(HANDLE h, ULONG ul, LPVOID lp)
{
	return TRUE;
}

// module getter.
winampDSPModule* getModule(int which);

void config(struct winampDSPModule* tm);
int init(struct winampDSPModule* tm);
void quit(struct winampDSPModule* tm);
int eliminate_samples_none(struct winampDSPModule* tm, short int* samples, int samplect, int bps, int nch, int srate);
int eliminate_samples_left(struct winampDSPModule* tm, short int* samples, int samplect, int bps, int nch, int srate);
int eliminate_samples_center(struct winampDSPModule* tm, short int* samples, int samplect, int bps, int nch, int srate);
int eliminate_samples_right(struct winampDSPModule* tm, short int* samples, int samplect, int bps, int nch, int srate);

// Module header, includes version, description, and address of the module retriever function
winampDSPHeader hdr = { DSP_HDRVER, "Channel Eliminator", getModule };

// no channel eliminator
winampDSPModule modnone = {
	"(None)",
	0,	// hwndParent
	0,	// hDllInstance
	config,
	init,
	eliminate_samples_none,
	quit
};

// left channel eliminator
winampDSPModule modleft = {
	"Eliminate Left Channel",
	0,	// hwndParent
	0,	// hDllInstance
	config,
	init,
	eliminate_samples_left,
	quit
};

// center channel eliminator
winampDSPModule modcenter = {
	"Eliminate Center Channel",
	0,	// hwndParent
	0,	// hDllInstance
	config,
	init,
	eliminate_samples_center,
	quit
};

// right channel eliminator
winampDSPModule modright = {
	"Eliminate Right Channel",
	0,	// hwndParent
	0,	// hDllInstance
	config,
	init,
	eliminate_samples_right,
	quit
};

// only exported symbol. returns our main header.
__declspec(dllexport) winampDSPHeader* winampDSPGetHeader2()
{
	return &hdr;
}

// getmodule routine from the main header.
winampDSPModule* getModule(int which)
{
	switch (which)	{
		case 0: return &modnone;
		case 1: return &modleft;
		case 2: return &modcenter;
		case 3: return &modright;
		default:return 0;
	}
}

// Called when user clicks configuration for the module
void config(struct winampDSPModule* tm)
{
	MessageBox(tm->hwndParent,"Freeware (f) 2001, Al Stevens",
									"Configuration",MB_OK);
}

int init(struct winampDSPModule* tm)
{
	return 0;
}
void quit(struct winampDSPModule* tm)
{
}

int eliminate_samples_none(struct winampDSPModule* tm, short int* samples, int samplect, int bps, int nch, int srate)
{
	return samplect;
}

void remove_left(short* a)
{
	a[0] = a[1];
}

void remove_center(short* a)
{
	int l, r;
	l = a[1]-a[0];
	r = a[0]-a[1];		
	if (l < -32768)
		l = -32768;
	if (l > 32767)
		l = 32767;
	if (r < -32768)
		r = -32768;
	if (r > 32767)
		r = 32767;
	a[0] = l;
	a[1] = r;
}

void remove_right(short* a)
{
	a[1] = a[0];
}

int eliminate_samples_left(struct winampDSPModule* tm, short int* samples, int samplect, int bps, int nch, int srate)
{
	int n = samplect;
	short* a = samples;
	while (n--)	{
		remove_left(a);
		a+=2;
	}
	return samplect;
}

int eliminate_samples_center(struct winampDSPModule* tm, short int* samples, int samplect, int bps, int nch, int srate)
{
	int n = samplect;
	short* a = samples;
	while (n--)	{
		remove_center(a);
		a+=2;
	}
	return samplect;
}

int eliminate_samples_right(struct winampDSPModule* tm, short int* samples, int samplect, int bps, int nch, int srate)
{
	int n = samplect;
	short* a = samples;
	while (n--)	{
		remove_right(a);
		a+=2;
	}
	return samplect;
}

