
function WMNoise = WatermarkNoiseGenerator(input, patternMatrix, parameter) 
% WmNoise = WatermarkNoiseGenerator(input, patternMatrix, Blocksize) 
% Generates the watermark noise. The alterations are performed according to
% the patternMatrix.     
%
% See also WRITE.
%
% Copyright (c) 2001 by Fraunhofer-IGD
% $Revision: 1.0 $  $Date: 2001/07/12 $
%
% M.Arnold, 07/01
%
%
% -- INPUT --
% input: Blocksize x BlocksPerFrame matrix conaining the samples for the
% different blocks.
%
% patternMatrix: Blocksize x BlocksPerFrame matrix conaining the
% values [0, 1 , -1] to specify the change of the frequency coefficient.
% 
% parameter: parameter struct containing Blocksize, BlocksPerFrame and vector
% of frequency indexes where the watermark will be embedded.  
%
% -- OUTPUT --
% WmNoise: Blocksize x BlocksPerFrame matrix conaining the watermark samples
% for the different blocks.
%-------------
       
global FFT_SIZE

% --- Set Parameter ---
BlocksPerFrame = parameter.BlocksPerFrame;
Blocksize = parameter.Blocksize; 
% ---------------------

% Fourier transform the original signal  
inputFFT = fft( input );

% Multiply the signal with the generated pattern   
WMNoiseFFT = (inputFFT .* patternMatrix)./(abs(inputFFT) + eps);

% Transform back to time domain
WMNoise = ifft(WMNoiseFFT);